Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(159)

Unified Diff: third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h

Issue 1645433002: Basic implementation of @apply (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix expted.txt for failing test Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h
diff --git a/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h b/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h
index 81d69bd8ac721724e466a946dbd214cd86f6b2f6..c49b97f87c26d7d3d8f5b9f91b590b6f7d1f9b1b 100644
--- a/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h
+++ b/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h
@@ -32,12 +32,14 @@ private:
// These return false if we encounter a reference to an invalid variable with no fallback
// Resolves a range which may contain var() references
bool resolveTokenRange(CSSParserTokenRange, Vector<CSSParserToken>& result);
// Resolves the fallback (if present) of a var() reference, starting from the comma
bool resolveFallback(CSSParserTokenRange, Vector<CSSParserToken>& result);
// Resolves the contents of a var() reference
bool resolveVariableReference(CSSParserTokenRange, Vector<CSSParserToken>& result);
+ // Consumes and resolves an @apply rule
+ void resolveApplyAtRule(CSSParserTokenRange&, Vector<CSSParserToken>& result);
// These return null if the custom property is invalid

Powered by Google App Engine
@@ -32,12 +32,14 @@ private:
// These return false if we encounter a reference to an invalid variable with no fallback
- // Resolves a range which may contain var() references
+ // Resolves a range which may contain var() references or @apply rules
bool resolveTokenRange(CSSParserTokenRange, Vector<CSSParserToken>& result);
// Resolves the fallback (if present) of a var() reference, starting from the comma
This is Rietveld 408576698